p5
===

p5 is a Python library that provides high level drawing functionality
to help you quickly create simulations and interactive art using
Python. It combines the core ideas of `Processing
<https://processing.org/>`_ — learning to code in a visual context —
with Python's readability to make programming more accessible to
beginners, educators, and artists.

Example
-------

.. image:: https://github.com/p5py/p5/blob/develop/docs/_static/readme.gif

p5 programs are called "sketches" and are run as any other Python
program. The sketch above, for instance, draws a circle at the mouse
location that gets a random reddish color when the mouse is pressed
and is white otherwise; the size of the circle is chosen randomly. The
Python code for the sketch looks like:

.. code:: python

   from p5 import *

   def setup():
       size(640, 360)
       no_stroke()
       background(204)

   def draw():
       if mouse_is_pressed:
           fill(random_uniform(255), random_uniform(127), random_uniform(51), 127)
       else:
           fill(255, 15)

       circle_size = random_uniform(low=10, high=80)

       circle((mouse_x, mouse_y), circle_size)

   def key_pressed(event):
       background(204)

   run()

Documentation
-------------
The p5py documentation can be found here `p5 documentation
<http://p5.readthedocs.io>`_

Installation
------------

Take a look at the installation steps here in the `p5 installation page
<http://p5.readthedocs.io/en/latest/install.html>`_

License
-------

p5 is licensed under the GPLv3. See `LICENSE <LICENSE>`_ for more
details. p5 also includes the following components from other open
source projects:

- OpenGL shaders `from the Processing
  <https://github.com/processing/processing/tree/master/core/src/processing/opengl/shaders>`_
  project. Licensed under LGPL v2.1. See `LICENSES/lgpl-2.1.txt
  <LICENSES/lgpl-2.1.txt>`_ for the full license text.

All licenses for these external components are available in the
``LICENSES`` folder.
